;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "web-mode" "20250827.1315"
  "Major mode for editing web templates."
  '((emacs "23.1"))
  :url "https://web-mode.org"
  :commit "1eb0abb1a9bffbb33db7bbfc6efe5b48bf416d57"
  :revdesc "1eb0abb1a9bf"
  :keywords '("languages")
  :maintainers '(("François-Xavier Bois" . "fxbois@gmail.com")))
